@@ -1,12 +1,14 @@
+from enum import Enum
 from dataclasses import dataclass
 from datetime import datetime
 from math import ceil
 from typing import Type, Union, List, Tuple, Dict, TypedDict, Optional, TypeVar
 
 from py_dot.core.date import Period, DateParts
+from py_dot.data.summary_time_unit import SummaryTimeUnit
 
 
-class SummaryTimeUnit:
+class SummaryTimeUnits:
     year = 'year'
     month = 'month'
     date = 'date'
@@ -41,7 +43,7 @@ class SummaryCondition:
     def __init__(
             self,
             period: Period,
-            unit: Union[SummaryTimeUnit, Type[SummaryTimeUnit]] = SummaryTimeUnit,
+            units: Union[SummaryTimeUnits, Type[SummaryTimeUnits]] = SummaryTimeUnit,
             year_days: int = 365,
             month_days: int = 30,
             year_from: int = 3,
@@ -57,47 +59,53 @@ class SummaryCondition:
 
         days = ceil(duration_time / 86400)
 
-        if unit.year is not None:
+        if units.year is not None:
             if days >= year_days * year_from:
-                self.model = unit.year
+                self.unit = SummaryTimeUnit.year
+                self.model = units.year
                 self.begin = begin.y
                 self.end = end.y
                 return
 
-        if unit.month is not None:
-            if unit.date is None or days >= month_days * month_from:
-                self.model = unit.month
+        if units.month is not None:
+            if units.date is None or days >= month_days * month_from:
+                self.unit = SummaryTimeUnit.month
+                self.model = units.month
                 self.begin = begin.ym
                 self.end = end.ym
                 return
 
-        if unit.date is not None:
-            if unit.hour is None or days >= date_from:
-                self.model = unit.date
+        if units.date is not None:
+            if units.hour is None or days >= date_from:
+                self.unit = SummaryTimeUnit.date
+                self.model = units.date
                 self.begin = begin.ymd
                 self.end = end.ymd
                 return
 
-        if unit.hour is not None:
-            if unit.minute is None or days >= hour_from:
-                self.model = unit.hour
+        if units.hour is not None:
+            if units.minute is None or days >= hour_from:
+                self.unit = SummaryTimeUnit.hour
+                self.model = units.hour
                 self.begin = begin.ymdh
                 self.end = end.ymdh
                 return
 
-        if unit.minute is not None:
+        if units.minute is not None:
             if duration_time >= minute_from:
-                self.model = unit.minute
+                self.unit = SummaryTimeUnit.minute
+                self.model = units.minute
                 self.begin = begin.ymdhi
                 self.end = end.ymdhi
                 return
 
-        self.model = unit.default
+        self.unit = SummaryTimeUnit.second
+        self.model = units.default
         self.begin = begin.ymdhis
         self.end = end.ymdhis
 
     def __iter__(self):
-        return iter((self.model, self.begin, self.end))
+        return iter((self.model, self.begin, self.end, self.unit))
 
 
 class DataSummaryTime:
